@@ -71,7 +71,7 @@
   #endif
   // When this file is compiled into a shared library, ELF linkers need to
   // know which symbols are functions.
-  #if defined(__svr4__) || defined(__ELF__) || defined(__NetBSD__) || defined(__FreeBSD__) || defined(__ROSE__) || defined(_SEQUENT_) || defined(DGUX) || defined(_SCO_COFF) || defined(_SCO_ELF)
+  #if defined(__svr4__) || defined(__ELF__) || defined(__NetBSD__) || defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__ROSE__) || defined(_SEQUENT_) || defined(DGUX) || defined(_SCO_COFF) || defined(_SCO_ELF)
     #define DECLARE_FUNCTION(name) .type C(name),@function
   #else
     #define DECLARE_FUNCTION(name)
