@@ -36,7 +36,7 @@
 
   // When this file is compiled into a shared library, ELF linkers need to
   // know which symbols are functions.
-  #if defined(__NetBSD__) || defined(__svr4__)
+  #if defined(__NetBSD__) || defined(__OpenBSD__) || defined(__ELF__) || defined(__svr4__)
     #define DECLARE_FUNCTION(name) .type C(name),@function
   #else
     #define DECLARE_FUNCTION(name)
