@@ -11,6 +11,8 @@ CL_PROVIDE(cl_DF_globals)
 
 // Implementation.
 
+namespace cln {
+
 #if (cl_word_size==64)
 
 const cl_DF cl_DF_0 = allocate_dfloat(0); // 0.0d0
@@ -29,4 +31,6 @@ const cl_DF cl_DF_minus1 = encode_DF(-1,1,bit(DF_mant_len-32),0); // -1.0d0
 
 #endif
 
+}  // namespace cln
+
 CL_PROVIDE_END(cl_DF_globals)
