@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_dfloat.h"
+#include "cln/dfloat.h"
 
 
 // Implementation.
@@ -12,8 +12,10 @@
 #include "cl_N.h"
 #include "cl_DF.h"
 
+namespace cln {
+
 MAYBE_INLINE
-uint32 cl_equal_hashcode (const cl_DF& x)
+uint32 equal_hashcode (const cl_DF& x)
 {
 	var cl_signean sign;
 	var sintL exp;
@@ -30,3 +32,5 @@ uint32 cl_equal_hashcode (const cl_DF& x)
 #endif
 	return equal_hashcode_low(msd,exp,sign);
 }
+
+}  // namespace cln
