@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_float.h"
+#include "cln/float.h"
 
 
 // Implementation.
 
 #include "cl_F.h"
 
+namespace cln {
+
 const cl_F_div_t ceiling2 (const cl_F& x, const cl_F& y)
 {
 // Methode:
@@ -20,3 +22,5 @@ const cl_F_div_t ceiling2 (const cl_F& x, const cl_F& y)
 	var cl_F& r = q_r.remainder;
 	return cl_F_div_t(q,y*r);
 }
+
+}  // namespace cln
