@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_ffloat.h"
+#include "cln/ffloat.h"
 
 
 // Implementation.
 
 #include "cl_FF.h"
 
+namespace cln {
+
 const cl_FF ftruncate (const cl_FF& x)
 {
 // Methode:
@@ -32,3 +34,5 @@ const cl_FF ftruncate (const cl_FF& x)
                 );
         }   }
 }
+
+}  // namespace cln
