@@ -4,13 +4,16 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_ffloat.h"
+#include "cln/ffloat.h"
 
 
 // Implementation.
 
 #include "cl_FF.h"
 #include "cl_ieee.h"
+
+namespace cln {
+
 NEED_IEEE_FLOATS()
 
 const cl_FF operator- (const cl_FF& x1, const cl_FF& x2)
@@ -30,3 +33,5 @@ const cl_FF operator- (const cl_FF& x1, const cl_FF& x2)
         { return x1 + allocate_ffloat(x2_ ^ bit(31)); }
   #endif
 }
+
+}  // namespace cln
