@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_ffloat.h"
+#include "cln/ffloat.h"
 
 
 // Implementation.
 
 #include "cl_FF.h"
 
+namespace cln {
+
 const cl_FF operator- (const cl_FF& x)
 {
 // Methode:
@@ -21,3 +23,5 @@ const cl_FF operator- (const cl_FF& x)
       else
         return allocate_ffloat( x_ ^ bit(31) );
 }
+
+}  // namespace cln
