@@ -4,20 +4,22 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_ffloat_class.h"
+#include "cln/ffloat_class.h"
 
 
 // Implementation.
 
-#include "cl_ffloat.h"
-#include "cl_input.h"
-#include "cl_float_io.h"
+#include "cln/ffloat.h"
+#include "cln/input.h"
+#include "cln/float_io.h"
+
+namespace cln {
 
 cl_read_flags cl_FF_read_flags = {
 	syntax_ffloat,
 	lsyntax_all,
 	10,
-	{ cl_float_format_ffloat, cl_float_format_lfloat_min, cl_false }
+	{ float_format_ffloat, float_format_lfloat_min, cl_false }
 };
 
 cl_FF::cl_FF (const char * string)
@@ -25,3 +27,5 @@ cl_FF::cl_FF (const char * string)
 	pointer = as_cl_private_thing(
 		As(cl_FF)(read_float(cl_FF_read_flags,string,NULL,NULL)));
 }
+
+}  // namespace cln
