@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_ffloat.h"
+#include "cln/ffloat.h"
 
 
 // Implementation.
@@ -19,6 +19,8 @@
 #include "cl_F.h"
 #include "dfloat/cl_DF.h"
 
+namespace cln {
+
 MAYBE_INLINE
 const cl_idecoded_float integer_decode_float (const cl_FF& x)
 {
@@ -29,8 +31,12 @@ const cl_idecoded_float integer_decode_float (const cl_FF& x)
 	                        );
 }
 
+}  // namespace cln
+
 #else
 
+namespace cln {
+
 MAYBE_INLINE
 const cl_idecoded_float integer_decode_float (const cl_FF& x)
 {
@@ -51,4 +57,6 @@ const cl_idecoded_float integer_decode_float (const cl_FF& x)
 	       );
 }
 
+}  // namespace cln
+
 #endif
