@@ -4,12 +4,16 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_lfloat.h"
+#include "cln/lfloat.h"
 
 
 // Implementation.
 
+namespace cln {
+
 const cl_LF min (const cl_LF& x, const cl_LF& y)
 {
 	return (x <= y ? x : y);
 }
+
+}  // namespace cln
