@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_lfloat.h"
+#include "cln/lfloat.h"
 
 
 // Implementation.
@@ -15,9 +15,13 @@
 #define MAYBE_INLINE inline
 #include "cl_LF_zerop.cc"
 
+namespace cln {
+
 MAYBE_INLINE2
 uintL float_precision (const cl_LF& x)
 {
 	if (zerop(x)) return 0;
 	return intDsize*(uintL)(TheLfloat(x)->len);
 }
+
+}  // namespace cln
