@@ -1,16 +1,18 @@
-// as_cl_F().
+// cl_F_As().
 
 // General includes.
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_float.h"
+#include "cln/float.h"
 
 
 // Implementation.
 
 #include "cl_N.h"
 
+namespace cln {
+
 inline cl_boolean cl_F_p (const cl_number& x)
 {
 	if (!x.pointer_p())
@@ -27,7 +29,7 @@ inline cl_boolean cl_F_p (const cl_number& x)
 	return cl_false;
 }
 
-const cl_F& as_cl_F (const cl_number& x, const char * filename, int line)
+const cl_F& cl_F_As (const cl_number& x, const char * filename, int line)
 {
 	if (cl_F_p(x)) {
 		DeclareType(cl_F,x);
@@ -35,3 +37,5 @@ const cl_F& as_cl_F (const cl_number& x, const char * filename, int line)
 	} else
 		cl_as_error(x,"a floating-point number",filename,line);
 }
+
+}  // namespace cln
