@@ -12,6 +12,8 @@
 #include "cl_SF.h"
 #include "cl_LF.h"
 
+namespace cln {
+
 const cl_F cl_F_extendsqrt (const cl_F& x)
 {
 // Methode:
@@ -35,3 +37,5 @@ const cl_F cl_F_extendsqrt (const cl_F& x)
 	,	return extend(x,cl_LF_len_incsqrt(TheLfloat(x)->len));
 	);
 }
+
+}  // namespace cln
