@@ -6,7 +6,7 @@
 CL_PROVIDE(cl_F_mostneg)
 
 // Specification.
-#include "cl_float.h"
+#include "cln/float.h"
 
 // Implementation.
 
@@ -17,6 +17,8 @@ CL_PROVIDE(cl_F_mostneg)
 #include "cl_LF.h"
 #include "cl_LF_impl.h"
 
+namespace cln {
+
 // Exponent so gro wie mglich, Mantisse 1...1, Vorzeichen -.
 
 static const cl_SF most_negative_SF =
@@ -39,7 +41,7 @@ inline const cl_LF most_negative_LF (uintC len)
 	return erg;
 }
 
-const cl_F most_negative_float (cl_float_format_t f)
+const cl_F most_negative_float (float_format_t f)
 {
 	floatformatcase((uintL)f
 	,	return most_negative_SF;
@@ -49,4 +51,6 @@ const cl_F most_negative_float (cl_float_format_t f)
 	);
 }
 
+}  // namespace cln
+
 CL_PROVIDE_END(cl_F_mostneg)
