@@ -1,16 +1,18 @@
-// as_cl_I().
+// cl_I_As().
 
 // General includes.
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_integer.h"
+#include "cln/integer.h"
 
 
 // Implementation.
 
 #include "cl_N.h"
 
+namespace cln {
+
 // Cf. cl_I_p in cl_I_ring.cc.
 // But here, for better inlining in g++, it is preferrable to finish every
 // alternative with either "return cl_true;" or "return cl_false;".
@@ -28,7 +30,7 @@ inline cl_boolean cl_I_p (const cl_number& x)
 	return cl_false;
 }
 
-const cl_I& as_cl_I (const cl_number& x, const char * filename, int line)
+const cl_I& cl_I_As (const cl_number& x, const char * filename, int line)
 {
 	if (cl_I_p(x)) {
 		DeclareType(cl_I,x);
@@ -36,3 +38,5 @@ const cl_I& as_cl_I (const cl_number& x, const char * filename, int line)
 	} else
 		cl_as_error(x,"an integer",filename,line);
 }
+
+}  // namespace cln
