@@ -4,16 +4,18 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_integer_io.h"
+#include "cln/integer_io.h"
 
 
 // Implementation.
 
-#include "cl_io.h"
+#include "cln/io.h"
 #include "cl_I.h"
 #include "cl_DS.h"
 
-void print_integer (cl_ostream stream, unsigned int base, const cl_I& z)
+namespace cln {
+
+void print_integer (std::ostream& stream, unsigned int base, const cl_I& z)
 {
 	var cl_I abs_z;
 	if (minusp(z)) {
@@ -34,3 +36,5 @@ void print_integer (cl_ostream stream, unsigned int base, const cl_I& z)
 		do { fprintchar(stream,*ptr++); } until (--count==0);
 	}
 }
+
+}  // namespace cln
