@@ -73,10 +73,26 @@ class cl_heap_modint_ring_fix29 : public cl_heap_modint_ring {
 	SUBCLASS_cl_heap_modint_ring()
 public:
 	// Constructor.
-	cl_heap_modint_ring_fix29 (const cl_I& m)
-		: cl_heap_modint_ring (m, &std_setops, &fix29_addops, &fix29_mulops) {}
-	// Virtual destructor.
+	cl_heap_modint_ring_fix29 (const cl_I& m);
+	// Destructor.
 	~cl_heap_modint_ring_fix29 () {}
 };
 
+static void cl_modint_ring_fix29_destructor (cl_heap* pointer)
+{
+	(*(cl_heap_modint_ring_fix29*)pointer).~cl_heap_modint_ring_fix29();
+}
+
+cl_class cl_class_modint_ring_fix29 = {
+	cl_modint_ring_fix29_destructor,
+	cl_class_flags_modint_ring
+};
+
+// Constructor.
+inline cl_heap_modint_ring_fix29::cl_heap_modint_ring_fix29(const cl_I& m)
+	: cl_heap_modint_ring (m, &std_setops, &fix29_addops, &fix29_mulops)
+{
+	type = &cl_class_modint_ring_fix29;
+}
+
 }  // namespace cln
