@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_rational.h"
+#include "cln/rational.h"
 
 
 // Implementation.
 
 #include "cl_RA.h"
-#include "cl_integer.h"
+#include "cln/integer.h"
+
+namespace cln {
 
 const cl_RA abs (const cl_RA& r)
 {
@@ -21,3 +23,5 @@ const cl_RA abs (const cl_RA& r)
 	else
 		return r;
 }
+
+}  // namespace cln
