@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_real.h"
+#include "cln/real.h"
 
 
 // Implementation.
@@ -14,10 +14,12 @@
 
 #if 0 // 2 type dispatches
 
-#include "cl_rational.h"
-#include "cl_float.h"
+#include "cln/rational.h"
+#include "cln/float.h"
 #include "cl_R_div_t.h"
 
+namespace cln {
+
 const cl_R_fdiv_t ftruncate2 (const cl_R& x)
 {
 	if (rationalp(x)) {
@@ -32,16 +34,20 @@ const cl_R_fdiv_t ftruncate2 (const cl_R& x)
 	}
 }
 
+}  // namespace cln
+
 #else // 1 type dispatch
 
 #include "cl_RA.h"
-#include "cl_integer.h"
-#include "cl_sfloat.h"
-#include "cl_ffloat.h"
-#include "cl_dfloat.h"
-#include "cl_lfloat.h"
+#include "cln/integer.h"
+#include "cln/sfloat.h"
+#include "cln/ffloat.h"
+#include "cln/dfloat.h"
+#include "cln/lfloat.h"
 #include "cl_LF.h"
 
+namespace cln {
+
 const cl_R_fdiv_t ftruncate2 (const cl_R& x)
 {
 	realcase6(x
@@ -59,4 +65,6 @@ const cl_R_fdiv_t ftruncate2 (const cl_R& x)
 	);
 }
 
+}  // namespace cln
+
 #endif
