@@ -4,19 +4,21 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_real_class.h"
+#include "cln/real_class.h"
 
 
 // Implementation.
 
-#include "cl_input.h"
-#include "cl_real_io.h"
+#include "cln/input.h"
+#include "cln/real_io.h"
+
+namespace cln {
 
 cl_read_flags cl_R_read_flags = {
 	syntax_real,
 	lsyntax_all,
 	10,
-	{ cl_float_format_ffloat, cl_float_format_lfloat_min, cl_true }
+	{ float_format_ffloat, float_format_lfloat_min, cl_true }
 };
 
 cl_R::cl_R (const char * string)
@@ -24,3 +26,5 @@ cl_R::cl_R (const char * string)
 	pointer = as_cl_private_thing(
 		read_real(cl_R_read_flags,string,NULL,NULL));
 }
+
+}  // namespace cln
