@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_real.h"
+#include "cln/real.h"
 
 
 // Implementation.
@@ -22,5 +22,9 @@
 #include "cl_DF_signum.cc"
 #include "cl_LF_signum.cc"
 
+namespace cln {
+
 const cl_R signum (const cl_R& x)
 GEN_R_OP1_7(x, signum, return)
+
+}  // namespace cln
