@@ -4,14 +4,18 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_real_io.h"
+#include "cln/real_io.h"
 
 
 // Implementation.
 
-#include "cl_output.h"
+#include "cln/output.h"
 
-void print_real (cl_ostream stream, const cl_print_flags& flags, const cl_R& z)
+namespace cln {
+
+void print_real (std::ostream& stream, const cl_print_flags& flags, const cl_R& z)
 {
 	print_real(stream,(const cl_print_number_flags&)flags,z);
 }
+
+}  // namespace cln
