@@ -4,11 +4,13 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_timing.h"
+#include "cln/timing.h"
 
 
 // Implementation.
 
+namespace cln {
+
 const cl_time_duration operator+ (const cl_time_duration& a, const cl_time_duration& b)
 {
 	var uintL sum_sec = a.tv_sec + b.tv_sec;
@@ -19,3 +21,5 @@ const cl_time_duration operator+ (const cl_time_duration& a, const cl_time_durat
 	}
 	return cl_time_duration(sum_sec,sum_nsec);
 }
+
+}  // namespace cln
