@@ -6,8 +6,8 @@
 #include <cln/complex.h>
 #include <cln/real.h>
 #include <cln/random.h>
-#include <stdlib.h>
-#include <string.h>
+#include <cstdlib>
+#include <cstring>
 #include <cln/timing.h>
 
 int main (int argc, char * argv[])
