@@ -3,8 +3,8 @@
 #include <cln/float.h>
 #include <cln/real.h>
 #include <cln/random.h>
-#include <stdlib.h>
-#include <string.h>
+#include <cstdlib>
+#include <cstring>
 #include <cln/timing.h>
 using namespace cln;
 
